==> haskell-doctest-parallel-0.2.4-4-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-doctest-parallel.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 doctest-parallel
version:              0.2.4
visibility:           public
id:                   doctest-parallel-0.2.4-JbYPqZEYZ1Z164EO3lO7AW
key:                  doctest-parallel-0.2.4-JbYPqZEYZ1Z164EO3lO7AW
license:              MIT
copyright:            (c) 2009-2018 Simon Hengel, 2021-2022 Martijn Bastiaan
maintainer:           Martijn Bastiaan <martijn@hmbastiaan.nl>
author:               Martijn Bastiaan <martijn@hmbastiaan.nl>
homepage:             https://github.com/martijnbastiaan/doctest-parallel#readme
synopsis:             Test interactive Haskell examples
description:
    The doctest program checks examples in source code comments.  It is modeled
    after doctest for Python (<https://docs.python.org/3/library/doctest.html>).

    Documentation is at <https://github.com/martijnbastiaan/doctest-parallel#readme>.

category:             Testing
abi:                  cfcfee0877a968c766ce4422f81aa1bf
exposed:              True
exposed-modules:
    Language.Haskell.GhciWrapper Test.DocTest Test.DocTest.Helpers
    Test.DocTest.Internal.Extract Test.DocTest.Internal.GhcUtil
    Test.DocTest.Internal.Interpreter Test.DocTest.Internal.Location
    Test.DocTest.Internal.Options Test.DocTest.Internal.Parse
    Test.DocTest.Internal.Property Test.DocTest.Internal.Runner
    Test.DocTest.Internal.Runner.Example Test.DocTest.Internal.Util

hidden-modules:       Paths_doctest_parallel
import-dirs:          /usr/lib/ghc-9.0.2/site-local/doctest-parallel-0.2.4
library-dirs:         /usr/lib/ghc-9.0.2/site-local/doctest-parallel-0.2.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-doctest-parallel
hs-libraries:         HSdoctest-parallel-0.2.4-JbYPqZEYZ1Z164EO3lO7AW
depends:
    Cabal-3.4.1.0 Glob-0.10.2-Bil4QY2ejAxBhtPZtgUfaG base-4.15.1.0
    base-compat-0.12.2-l1EqrM7Qwu6Pq9d4drKFu
    code-page-0.2.1-2yvmeM0b2LT6XlGG4kufG5 containers-0.6.4.1
    deepseq-1.4.5.0 directory-1.3.6.2 exceptions-0.10.4
    extra-1.7.12-4bSpI4IkWdaJwsry1yajTZ filepath-1.4.2.1 ghc-9.0.2
    ghc-paths-0.1.0.12-7fRPaqGgnC488dNzs2elDi pretty-1.1.3.6
    process-1.6.13.2 random-1.2.1.1-KJ0FCJNKSsMBe9MmB5vC8X
    syb-0.7.2.2-8yUDZDN1zlNKFBJiDzETDr transformers-0.5.6.2
    unordered-containers-0.2.19.1-FjtN46r9B8VFoR43GpqwkA

haddock-interfaces:
    /usr/share/doc/haskell-doctest-parallel/html/doctest-parallel.haddock

haddock-html:         /usr/share/doc/haskell-doctest-parallel/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 z-doctest-parallel-z-spectests-modules
version:              0.2.4
package-name:         doctest-parallel
lib-name:             spectests-modules
id:
    doctest-parallel-0.2.4-9wpHrGqLT6IL0eet7oeGKz-spectests-modules

key:
    doctest-parallel-0.2.4-9wpHrGqLT6IL0eet7oeGKz-spectests-modules

license:              MIT
copyright:            (c) 2009-2018 Simon Hengel, 2021-2022 Martijn Bastiaan
maintainer:           Martijn Bastiaan <martijn@hmbastiaan.nl>
author:               Martijn Bastiaan <martijn@hmbastiaan.nl>
homepage:             https://github.com/martijnbastiaan/doctest-parallel#readme
synopsis:             Test interactive Haskell examples
description:
    The doctest program checks examples in source code comments.  It is modeled
    after doctest for Python (<https://docs.python.org/3/library/doctest.html>).

    Documentation is at <https://github.com/martijnbastiaan/doctest-parallel#readme>.

category:             Testing
abi:                  887c51cafad1c3c5166e7f6fb3d66e9e
exposed-modules:
    BugfixImportHierarchical.ModuleA BugfixImportHierarchical.ModuleB
    BugfixMultipleModules.ModuleA BugfixMultipleModules.ModuleB
    BugfixOutputToStdErr.Fib Color.Foo DosLineEndings.Fib Failing.Foo
    FailingMultiple.Foo It.Foo It.Setup LocalStderrBinding.A
    ModuleIsolation.TestA ModuleIsolation.TestB ModuleOptions.Foo
    Multiline.Multiline NonExposedModule.Exposed PropertyBool.Foo
    PropertyBoolWithTypeSignature.Foo PropertyFailing.Foo
    PropertyImplicitlyQuantified.Foo PropertyQuantified.Foo
    PropertySetup.Foo Setup.Foo SetupSkipOnFailure.Foo
    SystemIoImported.A TemplateHaskell.Foo TestBlankline.Fib
    TestCombinedExample.Fib TestCommentLocation.Foo
    TestDocumentationForArguments.Fib TestFailOnMultiline.Fib
    TestImport.ModuleA TestImport.ModuleB TestPutStr.Fib TestSimple.Fib
    TrailingWhitespace.Foo WithCInclude.Bar WithCbits.Bar

hidden-modules:       NonExposedModule.NoImplicitImport
import-dirs:          /usr/lib/ghc-9.0.2/site-local/doctest-parallel-0.2.4
library-dirs:         /usr/lib/ghc-9.0.2/site-local/doctest-parallel-0.2.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-doctest-parallel
hs-libraries:
    HSdoctest-parallel-0.2.4-9wpHrGqLT6IL0eet7oeGKz-spectests-modules

depends:
    base-4.15.1.0 doctest-parallel-0.2.4-JbYPqZEYZ1Z164EO3lO7AW
    template-haskell-2.17.0.0

haddock-interfaces:
    /usr/share/doc/haskell-doctest-parallel/html/doctest-parallel.haddock

haddock-html:         /usr/share/doc/haskell-doctest-parallel/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-doctest-parallel-0.2.4-5-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-doctest-parallel.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 doctest-parallel
version:              0.2.4
visibility:           public
id:                   doctest-parallel-0.2.4-7LOfhBUyQt930pKGd3WB3
key:                  doctest-parallel-0.2.4-7LOfhBUyQt930pKGd3WB3
license:              MIT
copyright:            (c) 2009-2018 Simon Hengel, 2021-2022 Martijn Bastiaan
maintainer:           Martijn Bastiaan <martijn@hmbastiaan.nl>
author:               Martijn Bastiaan <martijn@hmbastiaan.nl>
homepage:             https://github.com/martijnbastiaan/doctest-parallel#readme
synopsis:             Test interactive Haskell examples
description:
    The doctest program checks examples in source code comments.  It is modeled
    after doctest for Python (<https://docs.python.org/3/library/doctest.html>).

    Documentation is at <https://github.com/martijnbastiaan/doctest-parallel#readme>.

category:             Testing
abi:                  e8ebd63f95910f8492ec06ab023442b2
exposed:              True
exposed-modules:
    Language.Haskell.GhciWrapper Test.DocTest Test.DocTest.Helpers
    Test.DocTest.Internal.Extract Test.DocTest.Internal.GhcUtil
    Test.DocTest.Internal.Interpreter Test.DocTest.Internal.Location
    Test.DocTest.Internal.Options Test.DocTest.Internal.Parse
    Test.DocTest.Internal.Property Test.DocTest.Internal.Runner
    Test.DocTest.Internal.Runner.Example Test.DocTest.Internal.Util

hidden-modules:       Paths_doctest_parallel
import-dirs:          /usr/lib/ghc-9.0.2/site-local/doctest-parallel-0.2.4
library-dirs:         /usr/lib/ghc-9.0.2/site-local/doctest-parallel-0.2.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-doctest-parallel
hs-libraries:         HSdoctest-parallel-0.2.4-7LOfhBUyQt930pKGd3WB3
depends:
    Cabal-3.4.1.0 Glob-0.10.2-2hpHTQOFOu786tzr1Hmjwm base-4.15.1.0
    base-compat-0.12.2-l1EqrM7Qwu6Pq9d4drKFu
    code-page-0.2.1-2yvmeM0b2LT6XlGG4kufG5 containers-0.6.4.1
    deepseq-1.4.5.0 directory-1.3.6.2 exceptions-0.10.4
    extra-1.7.12-DPTGYhuNp118MPDFhQYU8g filepath-1.4.2.1 ghc-9.0.2
    ghc-paths-0.1.0.12-7fRPaqGgnC488dNzs2elDi pretty-1.1.3.6
    process-1.6.13.2 random-1.2.1.1-LHneN0qmdBg2HhYYKMDrs5
    syb-0.7.2.2-JvKYfJw95RM7Y4GXhTvfdV transformers-0.5.6.2
    unordered-containers-0.2.19.1-1t66PwyRMuzEgWVME6Xx4r

haddock-interfaces:
    /usr/share/doc/haskell-doctest-parallel/html/doctest-parallel.haddock

haddock-html:         /usr/share/doc/haskell-doctest-parallel/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 z-doctest-parallel-z-spectests-modules
version:              0.2.4
package-name:         doctest-parallel
lib-name:             spectests-modules
id:
    doctest-parallel-0.2.4-6Y0v2iNYEEAFNZ2uBmyRFe-spectests-modules

key:
    doctest-parallel-0.2.4-6Y0v2iNYEEAFNZ2uBmyRFe-spectests-modules

license:              MIT
copyright:            (c) 2009-2018 Simon Hengel, 2021-2022 Martijn Bastiaan
maintainer:           Martijn Bastiaan <martijn@hmbastiaan.nl>
author:               Martijn Bastiaan <martijn@hmbastiaan.nl>
homepage:             https://github.com/martijnbastiaan/doctest-parallel#readme
synopsis:             Test interactive Haskell examples
description:
    The doctest program checks examples in source code comments.  It is modeled
    after doctest for Python (<https://docs.python.org/3/library/doctest.html>).

    Documentation is at <https://github.com/martijnbastiaan/doctest-parallel#readme>.

category:             Testing
abi:                  bdccee039634336e8eef38685b0df3f2
exposed-modules:
    BugfixImportHierarchical.ModuleA BugfixImportHierarchical.ModuleB
    BugfixMultipleModules.ModuleA BugfixMultipleModules.ModuleB
    BugfixOutputToStdErr.Fib Color.Foo DosLineEndings.Fib Failing.Foo
    FailingMultiple.Foo It.Foo It.Setup LocalStderrBinding.A
    ModuleIsolation.TestA ModuleIsolation.TestB ModuleOptions.Foo
    Multiline.Multiline NonExposedModule.Exposed PropertyBool.Foo
    PropertyBoolWithTypeSignature.Foo PropertyFailing.Foo
    PropertyImplicitlyQuantified.Foo PropertyQuantified.Foo
    PropertySetup.Foo Setup.Foo SetupSkipOnFailure.Foo
    SystemIoImported.A TemplateHaskell.Foo TestBlankline.Fib
    TestCombinedExample.Fib TestCommentLocation.Foo
    TestDocumentationForArguments.Fib TestFailOnMultiline.Fib
    TestImport.ModuleA TestImport.ModuleB TestPutStr.Fib TestSimple.Fib
    TrailingWhitespace.Foo WithCInclude.Bar WithCbits.Bar

hidden-modules:       NonExposedModule.NoImplicitImport
import-dirs:          /usr/lib/ghc-9.0.2/site-local/doctest-parallel-0.2.4
library-dirs:         /usr/lib/ghc-9.0.2/site-local/doctest-parallel-0.2.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-doctest-parallel
hs-libraries:
    HSdoctest-parallel-0.2.4-6Y0v2iNYEEAFNZ2uBmyRFe-spectests-modules

depends:
    base-4.15.1.0 doctest-parallel-0.2.4-7LOfhBUyQt930pKGd3WB3
    template-haskell-2.17.0.0

haddock-interfaces:
    /usr/share/doc/haskell-doctest-parallel/html/doctest-parallel.haddock

haddock-html:         /usr/share/doc/haskell-doctest-parallel/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
